<?php

namespace Shopping\Product\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Shopping\Product\Http\Requests\AttributegroupRequest;
use Shopping\Product\Interfaces\AttributegroupRepositoryInterface;
use Shopping\Product\Models\Attributegroup;
use Shopping\Product\Forms\Attributegroup as Form;

/**
 * APIController  class for attributegroup.
 */
class AttributegroupAPIController extends BaseController
{

    /**
     * Initialize attributegroup resource controller.
     *
     * @param type AttributegroupRepositoryInterface $attributegroup
     *
     * @return null
     */
    public function __construct(AttributegroupRepositoryInterface $attributegroup)
    {
        parent::__construct();
        $this->repository = $attributegroup;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Shopping\Product\Repositories\Criteria\AttributegroupResourceCriteria::class);
    }

    /**
     * Display a list of attributegroup.
     *
     * @return Response
     */
    public function index(AttributegroupRequest $request)
    {
        return $this->repository
            ->setPresenter(\Shopping\Product\Repositories\Presenter\AttributegroupPresenter::class)
            ->paginate();
    }

    /**
     * Display attributegroup.
     *
     * @param Request $request
     * @param Model   $attributegroup
     *
     * @return Response
     */
    public function show(AttributegroupRequest $request, Attributegroup $attributegroup)
    {
        return $attributegroup->setPresenter(\Shopping\Product\Repositories\Presenter\AttributegroupListPresenter::class);
        ;
    }

    /**
     * Create new attributegroup.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AttributegroupRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('product::attributegroup.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('product/attributegroup/' . $attributegroup->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('product/attributegroup');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the attributegroup.
     *
     * @param Request $request
     * @param Model   $attributegroup
     *
     * @return Response
     */
    public function update(AttributegroupRequest $request, Attributegroup $attributegroup)
    {
        try {
            $data = $request->all();

            $attributegroup->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('product::attributegroup.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('product/attributegroup/' . $attributegroup->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('product/attributegroup/' . $attributegroup->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the attributegroup.
     *
     * @param Model   $attributegroup
     *
     * @return Response
     */
    public function destroy(AttributegroupRequest $request, Attributegroup $attributegroup)
    {
        try {
            $attributegroup->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('product::attributegroup.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('product/attributegroup/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('product/attributegroup/' . $attributegroup->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
