<?php

namespace Shopping\Product\Policies;

use Litepie\User\Contracts\UserPolicy;
use Shopping\Product\Models\Attributegroup;

class AttributegroupPolicy
{

    /**
     * Determine if the given user can view the attributegroup.
     *
     * @param UserPolicy $user
     * @param Attributegroup $attributegroup
     *
     * @return bool
     */
    public function view(UserPolicy $user, Attributegroup $attributegroup)
    {
        if ($user->canDo('product.attributegroup.view') && $user->isAdmin()) {
            return true;
        }

        return $attributegroup->user_id == user_id() && $attributegroup->user_type == user_type();
    }

    /**
     * Determine if the given user can create a attributegroup.
     *
     * @param UserPolicy $user
     * @param Attributegroup $attributegroup
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('product.attributegroup.create');
    }

    /**
     * Determine if the given user can update the given attributegroup.
     *
     * @param UserPolicy $user
     * @param Attributegroup $attributegroup
     *
     * @return bool
     */
    public function update(UserPolicy $user, Attributegroup $attributegroup)
    {
        if ($user->canDo('product.attributegroup.edit') && $user->isAdmin()) {
            return true;
        }

        return $attributegroup->user_id == user_id() && $attributegroup->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given attributegroup.
     *
     * @param UserPolicy $user
     * @param Attributegroup $attributegroup
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Attributegroup $attributegroup)
    {
        return $attributegroup->user_id == user_id() && $attributegroup->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given attributegroup.
     *
     * @param UserPolicy $user
     * @param Attributegroup $attributegroup
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Attributegroup $attributegroup)
    {
        if ($user->canDo('product.attributegroup.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given attributegroup.
     *
     * @param UserPolicy $user
     * @param Attributegroup $attributegroup
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Attributegroup $attributegroup)
    {
        if ($user->canDo('product.attributegroup.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
