<?php

namespace Shopping\Product\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Shopping\Product\Models\Product;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Shopping\Product\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/product/product/*')) {
            Route::bind('product', function ($product) {
                $productrepo = $this->app->make('Shopping\Product\Interfaces\ProductRepositoryInterface');
                return $productrepo->findorNew($product);
            });
        }

        if (Request::is('*/product/category/*')) {
            Route::bind('category', function ($category) {
                $categoryrepo = $this->app->make('Shopping\Product\Interfaces\CategoryRepositoryInterface');
                return $categoryrepo->findorNew($category);
            });
        }

        if (Request::is('*/product/attribute/*')) {
            Route::bind('attribute', function ($attribute) {
                $attributerepo = $this->app->make('Shopping\Product\Interfaces\AttributeRepositoryInterface');
                return $attributerepo->findorNew($attribute);
            });
        }

        if (Request::is('*/product/attributegroup/*')) {
            Route::bind('attributegroup', function ($attributegroup) {
                $attributegrouprepo = $this->app->make('Shopping\Product\Interfaces\AttributegroupRepositoryInterface');
                return $attributegrouprepo->findorNew($attributegroup);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
